<?php 
return [
  'webhookName' => 'Webhook action name',
  'create' => 'Create',
  'delete' => 'Delete',
  'get' => 'GET',
  'post' => 'POST',
  'json' => 'JSON',
  'nothingSelected' => 'Nothing selected',
  'key' => 'Key',
  'name' => 'Name',
  'value' => 'Value',
];