<?php 
return [
  'requestHeaderNameRequired' => 'Request headers name is required',
  'requestHeaderValueRequired' => 'Request headers value is required',
  'requestBodyKeyRequired' => 'Request body key is required',
  'requestBodyValueRequired' => 'Request body value is required',
];