<?php 
return [
  'webhooks' => 'Webhooks',
  'log' => 'Log',
  'addWebhook' => 'Add Webhook',
  'editWebhook' => 'Update Webhook',
  'webhookName' => 'Webhook action name',
  'webhookFor' => 'Webhook for',
  'webhookAction' => 'Webhook Action',
  'requestUrl' => 'Request URL',
  'requestMethod' => 'Request method',
  'requestFormat' => 'Request format',
  'requestHeaders' => 'Request headers',
  'requestBody' => 'Request body',
  'addMore' => 'Add More',
  'responseCode' => 'Response Code',
  'createdAt' => 'Recorded On',
  'action' => 'Action',
  'runDebug' => 'Run in debug mode',
  'requestDetails' => 'Request Details',
  'response' => 'Response',
];